@@ -2,6 +2,7 @@
 # Unauthorized copying of this file, via any medium is strictly prohibited.
 import io
 import json
+import sys
 import time
 import urllib.parse
 import zipfile
@@ -48,6 +49,23 @@ class HTTPAdapterWithTCPKeepalive(HTTPAdapterWithSocketOptions):
         self.socket_options = HTTPConnection.default_socket_options + [
                                 (socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1),
                             ]
+
+        # Set the default keepalive params explicitly, the following values are equivalent to:
+        # net.ipv4.tcp_keepalive_time = 180
+        # net.ipv4.tcp_keepalive_intvl = 15
+        # net.ipv4.tcp_keepalive_probes = 5
+        if getattr(socket, 'TCP_KEEPINTVL', None) is not None:
+            self.socket_options += [(socket.IPPROTO_TCP, socket.TCP_KEEPINTVL, 15)]
+        elif sys.platform == 'darwin':
+            TCP_KEEPALIVE = getattr(socket, 'TCP_KEEPALIVE', 0x10)
+            self.socket_options += [(socket.IPPROTO_TCP, TCP_KEEPALIVE, 15)]
+
+        if getattr(socket, 'TCP_KEEPCNT', None) is not None:
+            self.socket_options += [(socket.IPPROTO_TCP, socket.TCP_KEEPCNT, 5)]
+
+        if getattr(socket, 'TCP_KEEPIDLE', None) is not None:
+            self.socket_options += [(socket.IPPROTO_TCP, socket.TCP_KEEPIDLE, 180)]
+
         super(HTTPAdapterWithTCPKeepalive, self).__init__(*args, **kwargs)
 
 
